@@ -21,6 +21,7 @@
  * 02110-1301 USA
  *
  */
+#include<QSettings>
 #include "exethread.h"
 
 ExeThread::ExeThread(QObject *parent)
@@ -74,7 +75,15 @@ int ExeThread::syst(const char *cmd)
 
 void ExeThread::run()
 {
-    QString temp=QDir::currentPath()+"/.temp";
+    QString argvString="";
+    QSettings settings("SJCE", "edicom");
+    settings.beginGroup("BuildSettings");
+    if(settings.value("enable").toBool()){
+        argvString=settings.value("arguments").toString();
+    }
+    settings.endGroup();
+
+    QString temp=QDir::currentPath()+"/.temp "+argvString;
         syst(temp.toAscii().data());// </tmp/.PIN > /tmp/.POUT");
         this->sleep(2);
 }
