@@ -55,7 +55,8 @@ int main(int argc, char *argv[])
     QTextStream out(&file);
     QString temp=out.readAll();
 
-    QString fileContent="`printf \"\\ndeb http://repository.maemo.org fremantle/sdk free non-free\\n\" >> /etc/apt/sources.list`\napt-get update\napt-get install gcc\napt-get install libc6-dev\napt-get install linux-kernel-headers\napt-get install libgcc1\nwget http://repository.maemo.org/extras/pool/fremantle-1.2/free/g/gdb/gdb_6.8.50.20090417-0maemo2+0m5_armel.deb\ndpkg -i gdb_6.8.50.20090417-0maemo2+0m5_armel.deb\napt-get install gdb\n";
+    QString fileContent="`printf \"\\ndeb http://repository.maemo.org fremantle/sdk free non-free\\n\" >> /etc/apt/sources.list`\napt-get update\napt-get install gcc\napt-get install libc6-dev\napt-get install linux-kernel-headers\napt-get install libgcc1\napt-get install gdb\n";
+    //wget http://repository.maemo.org/extras/pool/fremantle-1.2/free/g/gdb/gdb_6.8.50.20090417-0maemo2+0m5_armel.deb\ndpkg -i gdb_6.8.50.20090417-0maemo2+0m5_armel.deb
     QFile edicomFile("/home/user/edicom.sh");
     edicomFile.open(QIODevice::WriteOnly);
     QTextStream out2(&edicomFile);
